@@ -26,7 +26,6 @@
 #define __GTK_SOURCE_UNDO_MANAGER_H__
 
 #include <gtk/gtk.h>
-#include <gtksourceview/gtksourcetypes.h>
 
 G_BEGIN_DECLS
 
@@ -35,6 +34,7 @@ G_BEGIN_DECLS
 #define GTK_SOURCE_IS_UNDO_MANAGER(obj)             (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTK_SOURCE_TYPE_UNDO_MANAGER))
 #define GTK_SOURCE_UNDO_MANAGER_GET_INTERFACE(obj)  (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GTK_SOURCE_TYPE_UNDO_MANAGER, GtkSourceUndoManagerIface))
 
+typedef struct _GtkSourceUndoManager        	GtkSourceUndoManager;
 typedef struct _GtkSourceUndoManagerIface      	GtkSourceUndoManagerIface;
 
 struct _GtkSourceUndoManagerIface
